Package: dynasim
Type: Package
Title: Dynamics Similarity Coefficient
Version: 1.1
Authors@R: c(
    person(given = "Chun-Xiao", family = "Nie", 
           email = "niechunxiao2009@163.com", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7790-0803"))
  )
Description: Implements the quantile-graph based Dynamics Similarity Coefficient (DSC) for comparing intrinsic dynamics of time series.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-04-22 14:41:49 UTC; niech
Author: Chun-Xiao Nie [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7790-0803>)
Maintainer: Chun-Xiao Nie <niechunxiao2009@163.com>
Repository: CRAN
Date/Publication: 2026-04-23 20:00:09 UTC
Built: R 4.5.2; ; 2026-04-24 13:21:33 UTC; unix
