# Generated by roxygen2: do not edit by hand

export(cross_transition_matrix)
export(discretize_quantile)
export(dsc)
export(dsc_matrix)
export(gdsc)
export(gdsc_matrix)
export(mdsc)
export(transition_matrix)
