% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/discretize_quantile.R
\name{discretize_quantile}
\alias{discretize_quantile}
\title{Quantile discretization and transition probability matrix}
\usage{
discretize_quantile(x, n_s = 15)
}
\arguments{
\item{x}{Numeric vector representing the time series.}

\item{n_s}{Integer, number of states (quantile bins). Default is 15.}
}
\value{
Integer vector of state labels (1 to n_s).
}
\description{
Quantile discretization and transition probability matrix
}
\examples{
x <- rnorm(1000)
states <- discretize_quantile(x, n_s = 10)
}
