% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dsc.R
\name{dsc}
\alias{dsc}
\title{Compute Dynamics Similarity Coefficient (DSC) between two time series}
\usage{
dsc(x, y, n_s = 15, lag = 1, th_step = 0.005)
}
\arguments{
\item{x}{Numeric vector, first time series.}

\item{y}{Numeric vector, second time series.}

\item{n_s}{Integer, number of states. Default 15.}

\item{lag}{Integer, lag order. Default 1.}

\item{th_step}{Numeric, threshold step size. Default 0.005.}
}
\value{
A numeric value between 0 and 1, where higher values indicate greater similarity of intrinsic dynamics.
}
\description{
Compute Dynamics Similarity Coefficient (DSC) between two time series
}
\examples{
x <- arima.sim(model = list(ar = 0.5), n = 1000)
y <- arima.sim(model = list(ar = -0.5), n = 1000)
dsc(x, y, n_s = 15, lag = 1)
}
\references{
Nie, Chun-Xiao. "Distinguishing time series generated by different intrinsic dynamics using quantile graphs." Communications in Nonlinear Science and Numerical Simulation (2026): 110002.
}
