% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gdsc_matrix.R
\name{gdsc_matrix}
\alias{gdsc_matrix}
\title{Compute pairwise GDSC matrix for a collection of series}
\usage{
gdsc_matrix(X, n_s = 15, lags = 1:5, th_step = 0.005, show_progress = FALSE)
}
\arguments{
\item{X}{Matrix with time series in columns (rows = time points).}

\item{n_s}{Integer, number of states.}

\item{lags}{Vector of lag orders.}

\item{th_step}{Numeric, threshold step size.}

\item{show_progress}{Logical.}
}
\value{
Matrix of GDSC values between columns.
}
\description{
Compute pairwise GDSC matrix for a collection of series
}
\examples{
n <- 1000
X <- matrix(0,n,4)
X[,1]=arima.sim(model = list(ar = 0.5), n = n)
X[,2]=arima.sim(model = list(ar = 0.5), n = n)
X[,3]=arima.sim(model = list(ar = -0.5), n = n)
X[,4]=arima.sim(model = list(ar = -0.5), n = n)
gdsc_matrix(X, n_s = 10,lags=1:3,th_step = 0.005)
}
