% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cross_transition_matrix.R
\name{cross_transition_matrix}
\alias{cross_transition_matrix}
\title{Multivariate DSC (MDSC) Input: X and Y are matrices where columns are components}
\usage{
cross_transition_matrix(x, y, n_s = 15, lag = 1)
}
\arguments{
\item{x}{Numeric vector, first component.}

\item{y}{Numeric vector, second component.}

\item{n_s}{Integer, number of states.}

\item{lag}{Integer, lag order.}
}
\value{
Matrix of dimension n_s x n_s.
}
\description{
Multivariate DSC (MDSC) Input: X and Y are matrices where columns are components
}
