% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mdsc.R
\name{mdsc}
\alias{mdsc}
\title{Compute Multivariate Dynamics Similarity Coefficient (MDSC)}
\usage{
mdsc(X, Y, n_s = 15, lag = 1, th_step = 0.005)
}
\arguments{
\item{X}{Matrix or data.frame, each column is a component time series.}

\item{Y}{Matrix or data.frame, each column is a component time series.}

\item{n_s}{Integer, number of states.}

\item{lag}{Integer, lag order.}

\item{th_step}{Numeric, threshold step size.}
}
\value{
Numeric, MDSC value.
}
\description{
Compute Multivariate Dynamics Similarity Coefficient (MDSC)
}
\examples{
X <- matrix(rnorm(3000), ncol = 3)
Y <- matrix(rnorm(3000), ncol = 3)
mdsc(X, Y, n_s = 10)
}
\references{
Nie, Chun-Xiao. "Distinguishing time series generated by different intrinsic dynamics using quantile graphs." Communications in Nonlinear Science and Numerical Simulation (2026): 110002.
}
